package com.kakao.sdk.link40.sample;

import android.annotation.SuppressLint;
import android.content.Context;
import android.os.Bundle;
import android.app.Activity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.kakao.kakaolink.v4.KakaoLinkResponse;
import com.kakao.kakaolink.v4.KakaoLinkService;
import com.kakao.network.ErrorResult;
import com.kakao.network.callback.ResponseCallback;
import com.kakao.util.helper.log.Logger;

import java.util.HashMap;
import java.util.Map;

public class KakaoLink40Activity extends Activity implements View.OnClickListener {

    private LinearLayout templateLArgsList;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_kakao_link40);

        Button shareButton = (Button) findViewById(R.id.kakaolink_40_button);

        shareButton.setOnClickListener(this);

        templateLArgsList = (LinearLayout) findViewById(R.id.template_args_list);

        Button button = (Button) findViewById(R.id.button_add_template_arg);
        button.setOnClickListener(this);


        addTemplateArgInput("${androidAppParam}", "key1=value1");
        addTemplateArgInput("${iphoneAppParam}", "key1=value1");
        addTemplateArgInput("${senderParam}", "key1=value1");
    }


    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.kakaolink_40_button:
                shareViaKakaoLink40();
                break;
            case R.id.button_add_template_arg:
                addTemplateArgInput("", "");
                break;
            case R.id.button_delete_template_arg:
                deleteTemplateArgInput(v);
            default:
                break;
        }
    }

    private void addTemplateArgInput(final String key, final String value) {
        LayoutInflater inflater = (LayoutInflater) getApplicationContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
        @SuppressLint("InflateParams")
        LinearLayout layout = (LinearLayout) inflater.inflate(R.layout.layout_template_arg, null);

        EditText keyText = (EditText) layout.findViewById(R.id.template_arg_key);
        EditText valueText = (EditText) layout.findViewById(R.id.template_arg_value);
        keyText.setText(key);
        valueText.setText(value);
        Button button = (Button) layout.findViewById(R.id.button_delete_template_arg);
        button.setOnClickListener(this);
        templateLArgsList.addView(layout);
    }

    private void deleteTemplateArgInput(final View v) {
        ViewGroup parent = (ViewGroup) v.getParent().getParent();
        ViewGroup layout = (ViewGroup) parent.getParent();
        if (layout != null) {
            layout.removeView(parent);
        }
    }

    private Map<String, String> processTemplateArgs() {
        Map<String, String> templateArgs = new HashMap<String, String>();
        for (int i = 0; i < templateLArgsList.getChildCount(); i++) {
            LinearLayout layout = (LinearLayout) templateLArgsList.getChildAt(i);
            String key = ((EditText) layout.findViewById(R.id.template_arg_key)).getText().toString();
            String value = ((EditText) layout.findViewById(R.id.template_arg_value)).getText().toString();
            if (!key.isEmpty() && !value.isEmpty()) {
                templateArgs.put(key, value);
            }
        }
        return templateArgs;
    }

    private void shareViaKakaoLink40() {
        String templateId = ((TextView) findViewById(R.id.template_id)).getText().toString();
        Map<String, String> templateArgs = processTemplateArgs();
        KakaoLinkService.getInstance().send(this, templateId, templateArgs, new ResponseCallback<KakaoLinkResponse>() {
            @Override
            public void onFailure(ErrorResult errorResult) {
                Logger.e(errorResult.toString());
            }

            @Override
            public void onSuccess(KakaoLinkResponse result) {
                Logger.e("Succesfully sent KakaoLink 4.0 message");
            }
        });
    }
}
